@@ -23,6 +23,7 @@
 
 #include "player_info.h"
 #include "position.h"
+#include "logic_analyzer.h"
 
 #include <vector>
 #include <QGraphicsView>
@@ -52,18 +53,28 @@ public:
 public Q_SLOTS:
     /* Reset the game's state and start a new game, next/prev nagivation.*/
     void newGame();
-    void nextMove();
-    void prevMove();
+
+    void nextMove(); // unused
+    void prevMove(); // unsued
+
+    void onPieceMoveRequested(QPoint from, QPoint to);
 
 Q_SIGNALS:
+    void sendDebugInfo(QString msg);
     void playerInfoChanged();
     void positionChanged(const MPosition&);
+    void pieceMoved(QPoint from, QPoint to);
+    void invalidMove(QPoint from, QPoint to);
+    void check();
+    void pawnPromoted(QPoint where);
+    void pieceCapturedAt(QPoint where);
 
 private:
     // Formats player info, as seen on the mock-up. I am not sure the last line means turn or sth else.
     QString formatPlayerInfo(QString name, int rating, int turn, QString alignment) const;
     QString formatTimerInfo(QString time_remaining, bool isWhite) const;
     void addBoardToSceneGraph(QGraphicsScene *scene);
+    void setupStartPosition();
 
     /* Computes material for each side, using [1]
      * [1] http://en.wikipedia.org/wiki/Chess_piece_relative_value#Hans_Berliner.27s_system
@@ -71,19 +82,20 @@ private:
     int computeWhiteMaterial() const;
     int computeBlackMaterial() const;
     void updateMaterialInfo();
+    void updateMoveInfo(bool is_white_moving);
 
     /* Creates a scene graph containing all UI elements of the main view
      * (player cards, timer, board).
      */
     //QGraphicsScene* createScene();
 
-    std::vector<QString> createDummyGame() const;
-
-    // To simplify things, our current internal model is just a list of FEN
-    // strings, one for each position. I fully expect this to change in the future.
-    std::vector<QString> m_game;
+    //std::vector<QString> m_game;
     int m_half_move;
 
+    // The current position + logic_analyzer
+    MPosition m_position;
+    MLogicAnalyzer m_logic_analyzer;
+
     /* Stores player info, to be shown by the main window. */
     MPlayerInfo m_player_info;
 };
