@@ -2,6 +2,7 @@
  * you play and learn wherever you go.
  *
  * Copyright (C) 2009 Michael Hasselmann <michael@taschenorakel.de>
+ * Copyright (C) 2009 Mathias Hasselmann <mathias.hasselmann@maemo.org>
  *
  *
  * Miniature is free software: you can redistribute it and/or modify
@@ -20,33 +21,23 @@
 
 #include "graphics_board_item.h"
 
-#include <QPainterPath>
 #include <QGraphicsScene>
 #include <QTime>
-#include <QGraphicsItemAnimation>
 
 #include <cmath>
 
 using namespace Miniature;
 
-MGraphicsBoardItem::MGraphicsBoardItem(QGraphicsItem *parent)
-: QGraphicsSvgItem(parent),
-  m_selection_duration(2000),
-  m_frame(0),
-  m_frame_outline(4),
-  m_time_line(0)
-{
-    setupFrameAndTimeLine();
-}
-
-MGraphicsBoardItem::MGraphicsBoardItem(const QString &fileName, QGraphicsItem *parent)
-: QGraphicsSvgItem(fileName, parent),
+MGraphicsBoardItem::MGraphicsBoardItem(int board_size, QGraphicsItem *parent)
+: QGraphicsObject(parent),
+  m_board_size(board_size),
   m_selection_duration(2000),
   m_frame(0),
   m_frame_outline(4),
   m_time_line(0)
 {
     setupFrameAndTimeLine();
+    setFiltersChildEvents(true);
 }
 
 MGraphicsBoardItem::~MGraphicsBoardItem()
@@ -59,6 +50,9 @@ int MGraphicsBoardItem::getCellSize() const
 
 void MGraphicsBoardItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
+    static QTime profiling;
+    profiling.restart();
+
     static QGraphicsItem *active_item = 0;
     static QTime duration;
 
@@ -72,7 +66,8 @@ void MGraphicsBoardItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
     if(!active_item) // try to find an active item
     {
         active_item = (scene()->items(event->pos().x() - 1, event->pos().y() -1, 2, 2))[0];
-        if (active_item == this)
+
+        if (active_item == this || !active_item->data(0).toBool())
         {
            active_item = 0;
            resetFrame();
@@ -85,7 +80,7 @@ void MGraphicsBoardItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
         }
         //std::cout << "mouse_pressed: try to select" << std::endl;
     }
-    else // we have an active item.
+    else
     {
         const int cell_size = getCellSize();
         //std::cout << "mouse_pressed: sth was already selected" << std::endl;
@@ -98,13 +93,15 @@ void MGraphicsBoardItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
 
         if((src_x != dst_x) || (src_y != dst_y))
         {
-            active_item->setPos(QPointF(dst_x * cell_size, dst_y * cell_size));
-            Q_EMIT pieceMoved(QPoint(src_x, src_y), QPoint(dst_x, dst_y));
+            //active_item->setPos(QPointF(dst_x * cell_size, dst_y * cell_size));
+            Q_EMIT pieceMoveRequested(QPoint(src_x, src_y), QPoint(dst_x, dst_y));
         }
 
         active_item = 0;
         resetFrame();
     }
+
+    Q_EMIT sendDebugInfo(QString("MGBI::mpe - update duration: %1 ms").arg(profiling.restart()));
 }
 
 void MGraphicsBoardItem::setupFrameAndTimeLine()
@@ -154,3 +151,24 @@ void MGraphicsBoardItem::resetFrame()
     m_frame->hide();
     m_frame->setOpacity(1);
 }
+
+QRectF MGraphicsBoardItem::boundingRect() const
+{
+    return QRectF(0, 0, m_board_size, m_board_size);
+}
+
+void MGraphicsBoardItem::addPiece(QGraphicsSvgItem *piece)
+{
+    m_pieces.append(piece);
+    piece->setParentItem(this);
+}
+
+void MGraphicsBoardItem::removePieces()
+{
+    for(MPiecesList::iterator iter = m_pieces.begin();
+        iter != m_pieces.end();
+        ++iter)
+    {
+        (*iter)->hide();
+    }
+}
