@@ -22,22 +22,12 @@
 #include "miniature.h"
 #include "board_view.h"
 
-#include <QGraphicsTextItem>
-#include <QPixmap>
-#include <QApplication>
-
-#ifdef Q_WS_HILDON
-//Includes for portrait mode support
-#  include <X11/Xlib.h>
-#  include <X11/Xatom.h>
-#  include <QtGui/QX11Info>
-#endif
-
 using namespace Miniature;
 
 MMainWindow::MMainWindow()
 : QMainWindow()
 {
+
     m_ui.setupUi(this);
     updatePlayerInfo();
 
@@ -45,23 +35,31 @@ MMainWindow::MMainWindow()
     connect(&m_game, SIGNAL(playerInfoChanged()),
             this, SLOT(updatePlayerInfo()));
 
+    // Add debugging output to Miniature app.
+    connect(&m_game, SIGNAL(sendDebugInfo(QString)),
+            this, SLOT(appendDebugOutput(QString)));
+    connect(m_ui.board_view, SIGNAL(sendDebugInfo(QString)),
+            this, SLOT(appendDebugOutput(QString)));
+
     // Connect game logic w/ board view.
     connect(&m_game, SIGNAL(positionChanged(const MPosition&)),
             m_ui.board_view, SLOT(drawPosition(const MPosition&)));
+    connect(m_ui.board_view, SIGNAL(pieceMoveRequested(QPoint, QPoint)),
+            &m_game, SLOT(onPieceMoveRequested(QPoint, QPoint)));
 
-    // Connect moves from board with main window.
-    connect(m_ui.board_view, SIGNAL(pieceMoved(QPoint, QPoint)),
+
+    // Connect moves from game controller with main window.
+    connect(&m_game, SIGNAL(pieceMoved(QPoint, QPoint)),
             this, SLOT(updateLastMove(QPoint, QPoint)));
 
     // Connect menu actions.
     connect(m_ui.new_game, SIGNAL(triggered()),
             &m_game, SLOT(newGame()));
-    connect(m_ui.next_move, SIGNAL(triggered()),
-            &m_game, SLOT(nextMove()));
-    connect(m_ui.prev_move, SIGNAL(triggered()),
-            &m_game, SLOT(prevMove()));
+    connect(m_ui.toggle_debug_output, SIGNAL(triggered()),
+            this, SLOT(toggleDebugOutput()));
 
     // Fix the font sizes, the Maemo5 style is totally wrong regarding that.
+    QFont small_font("helvetica", 8, QFont::Light);
     QFont big_font("helvetica", 16, QFont::Bold);
     QFont normal_font("helvetica", 14, QFont::DemiBold);
     m_ui.white_name->setFont(big_font);
@@ -71,25 +69,15 @@ MMainWindow::MMainWindow()
     m_ui.black_name->setFont(big_font);
     m_ui.black_rating->setFont(normal_font);
     m_ui.black_material->setFont(normal_font);
+    m_ui.debug->setFont(small_font);
+    m_ui.debug->hide();
 
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ForcePortraitOrientation, true);
     setAttribute(Qt::WA_Maemo5ForceLandscapeOrientation, false);
 #endif
-
-// taken 99% verbatim from http://taschenorakel.de/michael/2009/11/09/miniature-it-moves/#c592, thanks again gnuton!
-#ifdef Q_WS_HILDON
-    int value = 1;
-    Atom portraitSupport = XInternAtom(QX11Info::display(), "_HILDON_PORTRAIT_MODE_SUPPORT", False);
-    Atom portraitRequest = XInternAtom(QX11Info::display(), "_HILDON_PORTRAIT_MODE_REQUEST", False);
-    XChangeProperty(QX11Info::display(), winId(), portraitSupport, XA_CARDINAL, 32, PropModeReplace, (uchar *)&value, 1);
-    XChangeProperty(QX11Info::display(), winId(), portraitRequest, XA_CARDINAL, 32, PropModeReplace, (uchar *)&value, 1);
-#endif
 }
 
-MMainWindow::~MMainWindow()
-{}
-
 void MMainWindow::updatePlayerInfo()
 {
     MPlayerInfo info = m_game.getPlayerInfo();
@@ -106,18 +94,67 @@ void MMainWindow::updatePlayerInfo()
 void MMainWindow::updateLastMove(QPoint from, QPoint to)
 {
     m_ui.last_move->setText(QString(tr("Moved from [%1, %2] to [%3, %4]")).arg(from.x())
-                                                                         .arg(from.y())
-                                                                         .arg(to.x())
-                                                                         .arg(to.y()));
+                                                                          .arg(from.y())
+                                                                          .arg(to.x())
+                                                                          .arg(to.y()));
 }
 
-int main(int argc, char **argv)
+void MMainWindow::appendDebugOutput(QString msg)
+{
+    m_ui.debug->append(msg);
+}
+
+void MMainWindow::toggleDebugOutput()
+{
+    static bool toggled = true;
+
+    if (toggled)
+    {
+        m_ui.debug->show();
+    }
+    else
+    {
+        m_ui.debug->hide();
+    }
+
+    toggled = !toggled;
+}
+
+
+MDBusAdaptor::MDBusAdaptor(MMainWindow *window) 
+: QDBusAbstractAdaptor(window),
+  m_window(window)
+{}
+
+void MDBusAdaptor::top_application()
+{
+    qDebug() << __func__;
+    m_window->activateWindow();
+}
+
+int main (int argc, char ** argv)
 {
     QApplication app(argc, argv);
-    QObject::connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
+    MMainWindow window;
 
-    MMainWindow main;
-    main.show();
+    QDBusConnection session(QDBusConnection::sessionBus());
+
+    if (!session.registerService(SERVICE_NAME))
+    {
+        qWarning("Cannot register D-Bus service. Trying to activate other instance.");
+        session.call(QDBusMessage::createMethodCall(SERVICE_NAME, SERVICE_PATH,
+                                                    SERVICE_NAME, "top_application"));
+        return 1;
+    }
+
+    if (!session.registerObject(SERVICE_PATH, &window))
+    {
+        qFatal("Cannot register D-Bus service. Aborting.");
+        return 1;
+    }
+
+    new MDBusAdaptor(&window);
+    window.show();
 
     return app.exec();
 }
