@@ -21,15 +21,17 @@
 #ifndef MINIATURE_H__
 #define MINIATURE_H__
 
-#include "miniature.ui.h"
+//#include "miniature.ui.h"
 #include "game.h"
 #include "player_info.h"
+#include "board_view.h"
+#include "miniature_ui.h"
 
-#include <QMainWindow>
-#include <QPoint>
+#include <QtGui>
+#include <QtDBus>
 
-namespace Miniature
-{
+#define SERVICE_NAME "org.maemo.miniature"
+#define SERVICE_PATH "/org/maemo/miniature"
 
 class MMainWindow
 : public QMainWindow
@@ -38,22 +40,35 @@ class MMainWindow
 
 public:
     MMainWindow();
-    virtual ~MMainWindow();
 
 public Q_SLOTS:
     void updatePlayerInfo();
     void updateLastMove(QPoint from, QPoint to);
+    void appendDebugOutput(QString msg);
+    void toggleDebugOutput();
 
 private:
+    Ui::MMainWindow m_ui;
+
     /* Our internal game controller */
     Miniature::MGame m_game;
-
-    /* A reference to the internal scene view */
-    //QGraphicsView* m_view;
-
-    Ui::MMainWindow m_ui;
+    //Ui::MMainWindow m_ui;
 };
 
-}; // namespace Miniature
+class MDBusAdaptor
+: public QDBusAbstractAdaptor
+{
+    Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.maemo.miniature")
+
+public:
+    MDBusAdaptor(MMainWindow *window);
+
+public Q_SLOTS:
+    void top_application();
+
+private:
+    MMainWindow *m_window;
+};
 
 #endif // MINIATURE_H__
